function in_data = fem_input

% fem_input.m - input file for FEM analysis  

% 1-D flow problem. 3 nodes and two 2-node bar/pipe elements 

% Control Data: [   nodes            % Total number of nodes
%                   numel            % Total number of elements
%                   nodaldof1        % Max dof per node
%                   nodesperelement  % Max nodes per element
%                   numat            % Max mumber of materials
%                   ndimensions      % Number of space dimensions  ]

in_data.control = [3 2 1 2 2 1 ];

% Nodal Data: [ node# x1 x2 x3] 
in_data.ND = [   
   1   0.0;
   2   10.0;
   3   20.0];
   
% Material Property Data: [ 
%                      Element type for material no. 1
%                      Element parameter 1 (Hydraulic conductivity)
%                      Element parameter 2 (Cross-sectional area)
%                      Element parameter 3
%                      Element parameter 4
%                      Element parameter 5
 in_data.mater = [11 1e-06 10 0 0 0;
                  11 2e-06 10 0 0 0];                   

% Element Association Data: [ element# materialtype# node1# node2# ....] 
in_data.EL = [  
   1   1   1   2;
   2   2   2   3];

   
% Nodal Constraint Data: [ node# x1_disp x2_disp.... etc ] 
% 1 = fixed head; 0 = non-fixed head
in_data.CON = [  
   1   1;
   2   0;
   3   1];


% Nodal Load Data: [node# x1_load x2_load..... etc] 
% Magnitude of prescribed load OR displacement
in_data.LOAD = [ 
   1   2e1;
   2   0e1;
   3   2.5e1];

 